Cabin is a humanist sans inspired by Edward Johnston's and Eric Gill's typefaces with a touch of modernism. Cabin incorporates modern proportions, optical adjustments, and some elements of the geometric sans. It remains true to its roots, but has its own personality.

The Cabin font family comes in two variable fonts that includes a Condensed version, four weights plus true italics. The weight distribution is almost monotone, although top and bottom curves are slightly thin. Counters of the b, g, p and q are rounded and optically adjusted.

Cabin language support includes full coverage of Vietnamese, additional to all Western, Central, and South-Eastern European languages.

To contribute, see github.com/impallari/Cabin.